from setuptools import setup, find_packages

setup(
    name='Plan_Your_Workout',
    version='0.1.0',
    packages=find_packages(),
    author='Grupo 1',
    author_email='irati.artaraz@alumni.mondragon.edu',
    description='A Guide to Structuring Your Fitness Agenda',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://https://github.com/eddamarcos/BDATA4_Progra_Grupo1',  
    classifiers=[
        'Programming Language :: Python :: 3'
    ],
)
